==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-slow-stochastic-oscillator-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { SlowStochasticOscillatorIndicator } from "./SlowStochasticOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Slow Stochastic Oscillator indicator series.
 * Default required members: High, Low, Close
*
* `IgxSlowStochasticOscillatorIndicatorComponent` (SSO) displays the closing price relative to the high-low range over a given period of time. There are three types of Stochastic Oscillators: Fast, Slow, and Full. The Stochastic Oscillator is a momentum indicator that shows the relation of the current close price relative to the high/low range over a given time period using a scale of 0 to 100. It is based on the premise that prices will close near 100 in a rising market and closer to 0 in a declining market.
*
* The Fast Stochastic Oscillator Indicator is used to identify buying or selling divergences. The Slow Stochastic Oscillator uses a 3-day SMA and the Full Stochastic Oscillator is the Slow Stochastic Oscillator with time period.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `VolumeMemberPath`.
*
* ```html
* <igx-data-chart
*     width=500px
*     height=500px
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
*         dateTimeMemberPath="TimeStamp"
*         #xAxis>
*       </igx-ordinal-time-x-axis>
*     <igx-numeric-y-axis
*        #yAxis></igx-numeric-y-axis>
*     <igx-slow-stochastic-oscillator-indicator
*        [xAxis]="xAxis"
*        [yAxis]="yAxis"
*        volumeMemberPath="Volume"
*        highMemberPath="High"
*        lowMemberPath="Low">
*      </igx-slow-stochastic-oscillator-indicator>
* </igx-data-chart>
* ```
*/
var IgrSlowStochasticOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrSlowStochasticOscillatorIndicator, _super);
    function IgrSlowStochasticOscillatorIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrSlowStochasticOscillatorIndicator.prototype.createImplementation = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    Object.defineProperty(IgrSlowStochasticOscillatorIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrSlowStochasticOscillatorIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current SlowStochasticOscillatorIndicator object.
         * The typical, and initial, value for SlowStochasticOscillatorIndicator periods is 14.
        *
        * ```html
        * <igx-data-chart
        *     width=500px
        *     height=500px
        *     [dataSource]="data" >
        *     <igx-ordinal-time-x-axis
        *         dateTimeMemberPath="TimeStamp"
        *         #xAxis>
        *       </igx-ordinal-time-x-axis>
        *     <igx-numeric-y-axis
        *        #yAxis></igx-numeric-y-axis>
        *     <igx-slow-stochastic-oscillator-indicator
        *        [xAxis]="xAxis"
        *        [yAxis]="yAxis"
        *        closeMemberPath="Close"
        *        highMemberPath="High"
        *        lowMemberPath="Low"
        *        period=10>
        *      </igx-slow-stochastic-oscillator-indicator>
        * </igx-data-chart>
        * ```
        */
        get: function () {
            return this.i.qo;
        },
        set: function (v) {
            this.i.qo = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrSlowStochasticOscillatorIndicator;
}(IgrStrategyBasedIndicator));
export { IgrSlowStochasticOscillatorIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-slow-stochastic-oscillator-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { SlowStochasticOscillatorIndicator } from "./SlowStochasticOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Slow Stochastic Oscillator indicator series.
 * Default required members: High, Low, Close
*
* `IgrSlowStochasticOscillatorIndicator` (SSO) displays the closing price relative to the high-low range over a given period of time. There are three types of Stochastic Oscillators: Fast, Slow, and Full. The Stochastic Oscillator is a momentum indicator that shows the relation of the current close price relative to the high/low range over a given time period using a scale of 0 to 100. It is based on the premise that prices will close near 100 in a rising market and closer to 0 in a declining market.
*
* The Fast Stochastic Oscillator Indicator is used to identify buying or selling divergences. The Slow Stochastic Oscillator uses a 3-day SMA and the Full Stochastic Oscillator is the Slow Stochastic Oscillator with time period.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `VolumeMemberPath`.
*/
var IgrSlowStochasticOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrSlowStochasticOscillatorIndicator, _super);
    function IgrSlowStochasticOscillatorIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrSlowStochasticOscillatorIndicator.prototype.createImplementation = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    Object.defineProperty(IgrSlowStochasticOscillatorIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrSlowStochasticOscillatorIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current SlowStochasticOscillatorIndicator object.
         * The typical, and initial, value for SlowStochasticOscillatorIndicator periods is 14.
        */
        get: function () {
            return this.i.qq;
        },
        set: function (v) {
            this.i.qq = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrSlowStochasticOscillatorIndicator;
}(IgrStrategyBasedIndicator));
export { IgrSlowStochasticOscillatorIndicator };
